@@ -18,10 +18,12 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
+from .literals import GroupLifecycleEventsDesiredStatusType
 from .paginator import ListGroupResourcesPaginator, ListGroupsPaginator, SearchResourcesPaginator
 from .type_defs import (
     CreateGroupOutputTypeDef,
     DeleteGroupOutputTypeDef,
+    GetAccountSettingsOutputTypeDef,
     GetGroupConfigurationOutputTypeDef,
     GetGroupOutputTypeDef,
     GetGroupQueryOutputTypeDef,
@@ -37,6 +39,7 @@ from .type_defs import (
     TagOutputTypeDef,
     UngroupResourcesOutputTypeDef,
     UntagOutputTypeDef,
+    UpdateAccountSettingsOutputTypeDef,
     UpdateGroupOutputTypeDef,
     UpdateGroupQueryOutputTypeDef,
 )
@@ -140,6 +143,14 @@ class ResourceGroupsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#generate_presigned_url)
         """
 
+    def get_account_settings(self) -> GetAccountSettingsOutputTypeDef:
+        """
+        Retrieves the current status of optional features in Resource Groups.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups.html#ResourceGroups.Client.get_account_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#get_account_settings)
+        """
+
     def get_group(self, *, GroupName: str = ..., Group: str = ...) -> GetGroupOutputTypeDef:
         """
         Returns information about a specified resource group.
@@ -150,7 +161,8 @@ class ResourceGroupsClient(BaseClient):
 
     def get_group_configuration(self, *, Group: str = ...) -> GetGroupConfigurationOutputTypeDef:
         """
-        Returns the service configuration associated with the specified resource group.
+        Retrieves the service configuration associated with the specified resource
+        group.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups.html#ResourceGroups.Client.get_group_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#get_group_configuration)
@@ -210,7 +222,7 @@ class ResourceGroupsClient(BaseClient):
         NextToken: str = ...
     ) -> ListGroupsOutputTypeDef:
         """
-        Returns a list of existing resource groups in your account.
+        Returns a list of existing Resource Groups in your account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups.html#ResourceGroups.Client.list_groups)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#list_groups)
@@ -230,7 +242,8 @@ class ResourceGroupsClient(BaseClient):
         self, *, ResourceQuery: ResourceQueryTypeDef, MaxResults: int = ..., NextToken: str = ...
     ) -> SearchResourcesOutputTypeDef:
         """
-        Returns a list of AWS resource identifiers that matches the specified query.
+        Returns a list of Amazon Web Services resource identifiers that matches the
+        specified query.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups.html#ResourceGroups.Client.search_resources)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#search_resources)
@@ -262,6 +275,16 @@ class ResourceGroupsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#untag)
         """
 
+    def update_account_settings(
+        self, *, GroupLifecycleEventsDesiredStatus: GroupLifecycleEventsDesiredStatusType = ...
+    ) -> UpdateAccountSettingsOutputTypeDef:
+        """
+        Turns on or turns off optional features in Resource Groups.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/resource-groups.html#ResourceGroups.Client.update_account_settings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_resource_groups/client/#update_account_settings)
+        """
+
     def update_group(
         self, *, GroupName: str = ..., Group: str = ..., Description: str = ...
     ) -> UpdateGroupOutputTypeDef:
