@@ -6,9 +6,9 @@ Type annotations for resource-groups service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_resource_groups.type_defs import ResourceQueryTypeDef
+    from mypy_boto3_resource_groups.type_defs import AccountSettingsTypeDef
 
-    data: ResourceQueryTypeDef = {...}
+    data: AccountSettingsTypeDef = {...}
     ```
 """
 import sys
@@ -17,6 +17,8 @@ from typing import Dict, List, Mapping, Sequence
 from .literals import (
     GroupConfigurationStatusType,
     GroupFilterNameType,
+    GroupLifecycleEventsDesiredStatusType,
+    GroupLifecycleEventsStatusType,
     QueryErrorCodeType,
     QueryTypeType,
 )
@@ -32,6 +34,7 @@ else:
 
 
 __all__ = (
+    "AccountSettingsTypeDef",
     "ResourceQueryTypeDef",
     "GroupTypeDef",
     "ResponseMetadataTypeDef",
@@ -54,15 +57,18 @@ __all__ = (
     "TagInputRequestTypeDef",
     "UngroupResourcesInputRequestTypeDef",
     "UntagInputRequestTypeDef",
+    "UpdateAccountSettingsInputRequestTypeDef",
     "UpdateGroupInputRequestTypeDef",
     "GroupQueryTypeDef",
     "SearchResourcesInputRequestTypeDef",
     "UpdateGroupQueryInputRequestTypeDef",
     "DeleteGroupOutputTypeDef",
+    "GetAccountSettingsOutputTypeDef",
     "GetGroupOutputTypeDef",
     "GetTagsOutputTypeDef",
     "TagOutputTypeDef",
     "UntagOutputTypeDef",
+    "UpdateAccountSettingsOutputTypeDef",
     "UpdateGroupOutputTypeDef",
     "GroupConfigurationItemTypeDef",
     "ListGroupsInputRequestTypeDef",
@@ -85,6 +91,16 @@ __all__ = (
     "GetGroupConfigurationOutputTypeDef",
 )
 
+AccountSettingsTypeDef = TypedDict(
+    "AccountSettingsTypeDef",
+    {
+        "GroupLifecycleEventsDesiredStatus": GroupLifecycleEventsDesiredStatusType,
+        "GroupLifecycleEventsStatus": GroupLifecycleEventsStatusType,
+        "GroupLifecycleEventsStatusMessage": str,
+    },
+    total=False,
+)
+
 ResourceQueryTypeDef = TypedDict(
     "ResourceQueryTypeDef",
     {
@@ -298,6 +314,14 @@ UntagInputRequestTypeDef = TypedDict(
     },
 )
 
+UpdateAccountSettingsInputRequestTypeDef = TypedDict(
+    "UpdateAccountSettingsInputRequestTypeDef",
+    {
+        "GroupLifecycleEventsDesiredStatus": GroupLifecycleEventsDesiredStatusType,
+    },
+    total=False,
+)
+
 UpdateGroupInputRequestTypeDef = TypedDict(
     "UpdateGroupInputRequestTypeDef",
     {
@@ -368,6 +392,14 @@ DeleteGroupOutputTypeDef = TypedDict(
     },
 )
 
+GetAccountSettingsOutputTypeDef = TypedDict(
+    "GetAccountSettingsOutputTypeDef",
+    {
+        "AccountSettings": AccountSettingsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 GetGroupOutputTypeDef = TypedDict(
     "GetGroupOutputTypeDef",
     {
@@ -403,6 +435,14 @@ UntagOutputTypeDef = TypedDict(
     },
 )
 
+UpdateAccountSettingsOutputTypeDef = TypedDict(
+    "UpdateAccountSettingsOutputTypeDef",
+    {
+        "AccountSettings": AccountSettingsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateGroupOutputTypeDef = TypedDict(
     "UpdateGroupOutputTypeDef",
     {
